@@ -1,3 +1,5 @@
+import socket
+
 SOCKETCALL = {
     1: "socket",
     2: "bind",
@@ -19,16 +21,16 @@ SOCKETCALL = {
 }
 
 SOCKET_FAMILY = {
-     0: "AF_UNSPEC",
-     1: "AF_FILE",
-     2: "AF_INET",
-     3: "AF_AX25",
-     4: "AF_IPX",
-     5: "AF_APPLETALK",
-     6: "AF_NETROM",
-     7: "AF_BRIDGE",
-     8: "AF_ATMPVC",
-     9: "AF_X25",
+    0: "AF_UNSPEC",
+    1: "AF_FILE",
+    2: "AF_INET",
+    3: "AF_AX25",
+    4: "AF_IPX",
+    5: "AF_APPLETALK",
+    6: "AF_NETROM",
+    7: "AF_BRIDGE",
+    8: "AF_ATMPVC",
+    9: "AF_X25",
     10: "AF_INET6",
     11: "AF_ROSE",
     12: "AF_DECnet",
@@ -48,16 +50,31 @@ SOCKET_FAMILY = {
 }
 
 SOCKET_TYPE = {
-     1: "SOCK_STREAM",
-     2: "SOCK_DGRAM",
-     3: "SOCK_RAW",
-     4: "SOCK_RDM",
-     5: "SOCK_SEQPACKET",
+    1: "SOCK_STREAM",
+    2: "SOCK_DGRAM",
+    3: "SOCK_RAW",
+    4: "SOCK_RDM",
+    5: "SOCK_SEQPACKET",
     10: "SOCK_PACKET",
 }
 
+
+def formatSocketType(argument):
+    value = argument.value
+    text = []
+    if hasattr(socket, 'SOCK_CLOEXEC'):
+        cloexec = value & socket.SOCK_CLOEXEC
+        value &= ~socket.SOCK_CLOEXEC
+    else:
+        cloexec = False
+    text = SOCKET_TYPE.get(value, str(value))
+    if cloexec:
+        text += '|SOCK_CLOEXEC'
+    return text
+
+
 SOCKET_PROTOCOL = {
-     1: "IPPROTO_ICMP",
+    1: "IPPROTO_ICMP",
     58: "IPPROTO_ICMPV6",
 }
 
@@ -67,12 +84,11 @@ SETSOCKOPT_LEVEL = {
 }
 
 SETSOCKOPT_OPTNAME = {
-   # level 0 (SOL_IP)
-     1: "IP_TOS",
-   # level 1 (SOL_SOCKET)
-     2: "SO_REUSEADDR",
-     9: "SO_KEEPALIVE",
+    # level 0 (SOL_IP)
+    1: "IP_TOS",
+    # level 1 (SOL_SOCKET)
+    2: "SO_REUSEADDR",
+    9: "SO_KEEPALIVE",
     20: "SO_RCVTIMEO",
     21: "SO_SNDTIMEO",
 }
-
