@@ -6,14 +6,17 @@ from ptrace.error import PTRACE_ERRORS, writeError
 from logging import getLogger, INFO
 from ptrace.func_arg import FunctionArgument
 from ptrace.syscall.posix_arg import (
-    formatMmapProt, formatAccessMode, formatOpenMode, formatCloneFlags)
+    formatMmapProt, formatAccessMode, formatOpenFlags, formatCloneFlags, formatDirFd, formatOpenMode)
 from ptrace.func_call import FunctionCall
 from ptrace.syscall.socketcall import (setupSocketCall,
-    formatOptVal, formatSockaddr, formatSockaddrInStruct, formatSockaddrIn6Struct)
+                                       formatOptVal, formatSockaddr, formatSockaddrInStruct, formatSockaddrIn6Struct)
 from ptrace.syscall.socketcall_constants import SOCKETCALL
+import os
 import re
+
 from ptrace.os_tools import RUNNING_LINUX, RUNNING_FREEBSD
 from ptrace.syscall import FILENAME_ARGUMENTS
+from ptrace.syscall.socketcall_constants import formatSocketType
 if RUNNING_LINUX:
     from ptrace.syscall.linux_struct import (
         timeval, timespec, pollfd, rlimit, new_utsname, user_desc)
@@ -23,18 +26,23 @@ elif RUNNING_FREEBSD:
 else:
     SYSCALL_ARG_DICT = {}
 
+
 KNOWN_STRUCTS = []
 if RUNNING_LINUX:
-    KNOWN_STRUCTS.extend((timeval, timespec, pollfd, rlimit, new_utsname, user_desc))
-KNOWN_STRUCTS = dict( (struct.__name__, struct) for struct in KNOWN_STRUCTS )
+    KNOWN_STRUCTS.extend(
+        (timeval, timespec, pollfd, rlimit, new_utsname, user_desc))
+KNOWN_STRUCTS = dict((struct.__name__, struct) for struct in KNOWN_STRUCTS)
 
 ARGUMENT_CALLBACK = {
     # Prototype: callback(argument) -> str
     "access": {"mode": formatAccessMode},
-    "open": {"mode": formatOpenMode},
+    "open": {"flags": formatOpenFlags, "mode": formatOpenMode},
+    "openat": {"dirfd": formatDirFd, "flags": formatOpenFlags, "mode": formatOpenMode},
+    "name_to_handle_at": {"dirfd": formatDirFd},
     "mmap": {"prot": formatMmapProt},
     "mmap2": {"prot": formatMmapProt},
     "clone": {"flags": formatCloneFlags},
+    "socket": {"type": formatSocketType},
     "setsockopt": {"optval": formatOptVal},
 }
 
@@ -54,13 +62,16 @@ INTEGER_TYPES = set((
     "socklen_t", "pid_t", "uid_t", "gid_t",
 ))
 
+
 def iterBits(data):
     for char in data:
-        byte = ord(char)
+        byte = ord(chr(char))
         for index in range(8):
             yield ((byte >> index) & 1) == 1
 
+
 class SyscallArgument(FunctionArgument):
+
     def createText(self):
         value = self.value
         argtype = self.type
@@ -92,7 +103,8 @@ class SyscallArgument(FunctionArgument):
                     return str(value)
             if name == "args":
                 func_call = FunctionCall("socketcall", self.options)
-                setupSocketCall(func_call, self.function.process, self.function[0], self.value)
+                setupSocketCall(func_call, self.function.process,
+                                self.function[0], self.value)
                 text = "<%s>" % func_call.format()
                 return self.formatPointer(text, self.value)
         if syscall == "write" and name == "buf":
@@ -102,25 +114,28 @@ class SyscallArgument(FunctionArgument):
                 return self.readString(value, length)
         if name == "signum":
             return signalName(value)
-        if name in FILENAME_ARGUMENTS:
-            return self.readCString(value)
 
         # Remove "const " prefix
         if argtype.startswith("const "):
             argtype = argtype[6:]
 
+        if name in FILENAME_ARGUMENTS and argtype == "char *":
+            return self.readCString(value)
+
         # Format depending on the type
         if argtype.endswith("*"):
             try:
-                text = self.formatValuePointer(argtype[:-1])
+                # Strip in case there is a space between the name and '*'
+                text = self.formatValuePointer(argtype[:-1].strip())
                 if text:
                     return text
             except PTRACE_ERRORS as err:
-                writeError(getLogger(), err, "Warning: Format %r value error" % self, log_level=INFO)
+                writeError(
+                    getLogger(), err, "Warning: Format %r value error" % self, log_level=INFO)
             return formatAddress(self.value)
 
         # Array like "int[2]"
-        match = re.match("(.*)\[([0-9])+\]", argtype)
+        match = re.match(r"(.*)\[([0-9])+\]", argtype)
         if match:
             basetype = match.group(1)
             count = int(match.group(2))
@@ -159,47 +174,54 @@ class SyscallArgument(FunctionArgument):
             struct = KNOWN_STRUCTS[argtype]
             return self.readStruct(address, struct)
         if RUNNING_LINUX and argtype == "fd_set":
-            fd_set = self.readBits(address, FD_SETSIZE)
-            return self.formatPointer("<fdset=(%s)>" % fd_set, address)
+            # The function is either select or pselect, so arg[0] is nfds
+            nfds = self.function.arguments[0].value
+            fd_set = filter(lambda x: int(x) < nfds, self.readBits(address, FD_SETSIZE))
+            return self.formatPointer("[%s]" % " ".join(fd_set), address)
 
         syscall = self.function.name
         if syscall == "rt_sigprocmask" and argtype == "sigset_t":
             size = self.function["sigsetsize"].value * 8
+
             def formatter(key):
                 key += 1
                 return signalName(key)
             fd_set = self.readBits(address, size, format=formatter)
-            return self.formatPointer("<sigset=(%s)>" % fd_set, address)
+            return self.formatPointer("<sigset=(%s)>" % " ".join(fd_set), address)
         return None
 
     def readBits(self, address, count, format=str):
-        bytes = self.function.process.readBytes(address, count//8)
-        fd_set = [ format(index) for index, bit in enumerate(iterBits(bytes)) if bit ]
-        return ", ".join(fd_set)
+        bytes = self.function.process.readBytes(address, count // 8)
+        fd_set = [format(index)
+                  for index, bit in enumerate(iterBits(bytes)) if bit]
+        return fd_set
 
     def readCString(self, address):
         if address:
             max_size = self.options.string_max_length
-            char, truncated = self.function.process.readCString(address, max_size)
-            char = repr(char)
+            data, truncated = self.function.process.readCString(
+                address, max_size)
+            text = os.fsdecode(data)
+            text = repr(text)
             if truncated:
-                char += "..."
+                text += "..."
         else:
-            char = "NULL"
-        return self.formatPointer(char, address)
+            text = "NULL"
+        return self.formatPointer(text, address)
 
     def readString(self, address, size):
         if address:
             max_len = self.options.string_max_length
             truncated = (max_len < size)
             size = min(size, max_len)
-            bytes = self.function.process.readBytes(address, size)
-            bytes = repr(bytes)
+            data = self.function.process.readBytes(address, size)
+            text = os.fsdecode(data)
+            text = repr(text)
             if truncated:
-                bytes += "..."
+                text += "..."
         else:
-            bytes = "NULL"
-        return self.formatPointer(bytes, address)
+            text = "NULL"
+        return self.formatPointer(text, address)
 
     def readCStringArray(self, address):
         if not address:
@@ -224,4 +246,3 @@ class SyscallArgument(FunctionArgument):
             callback = STRUCT_CALLBACK[struct]
             return callback(self, name, value)
         return None
-
